@@ -11,7 +11,7 @@ async fn index(res: &mut Response) {
 async fn upload(req: &mut Request, res: &mut Response) {
     let file = req.get_file("file").await;
     if let Some(file) = file {
-        let dest = format!("temp/{}", file.filename().unwrap_or_else(|| "file".into()));
+        let dest = format!("temp/{}", file.file_name().unwrap_or_else(|| "file".into()));
         println!("{}", dest);
         if let Err(e) = std::fs::copy(&file.path, Path::new(&dest)) {
             res.set_status_code(StatusCode::INTERNAL_SERVER_ERROR);
